==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/R/yeastPkgBuilder.R <==
# This function builds a data package for yeast geno.

yeastPkgBuilder <- function(pkgName, pkgPath, base = "", srcUrls = c(KEGG
                            = getSrcUrl("KEGG", organism = "yeast"),
                            GO = getSrcUrl("GO")), version = "1.1.0",
                            makeXML = TRUE, author = list(author = "who",
                            maintainer = "who@email.com"), fromWeb =
                            TRUE){

    getUniCol4Yeast <- function(){
        if(base != ""){
            return(c("PMID", "ORF", "CHR", "DESCRIPTION", "GENENAME"))
        }else{
            return(c("PMID", "CHR", "DESCRIPTION", "GENENAME"))
        }
    }
    getMultCol4Yeast <- function(){
        return("ALIAS")
    }

    if(!is.na(srcUrls["KEGG"])){
        kegg <- KEGG(srcUrl = srcUrls["KEGG"], organism = "yeast")
    }
    if(!is.na(srcUrls["GO"])){
        go <- GO(srcUrl = srcUrls["GO"])
    }

    makeSrcInfo()
    createEmptyDPkg(pkgName, pkgPath, force = TRUE)
    annotation <- yeastAnn(base)
    annotation <- as.matrix(annotation)
    colnames(annotation) <- toupper(colnames(annotation))
    if(makeXML){
        multC <- c("PMID", "ALIAS")
        typeC <- c("GO", "CHRLOC")
        XMLOut <- file.path(pkgPath, paste(pkgName, ".xml", sep = ""))
        fileToXML(targetName = pkgName, outName = XMLOut,
                  inName = annotation[, colnames(annotation) != "EVI"],
                  colNames = "", idColName = "PROBE", multColNames = multC,
                  typeColNames = typeC, isFile = FALSE, version = version)
    }
    # Write elements that has one to one mappings
    for(i in getUniCol4Yeast()){
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(annotation[,"PROBE"], as.vector(annotation[,i]), env)
        assign(paste(pkgName, i, sep = ""), env)
        save(list = paste(pkgName, i, sep = ""), file =  file.path(pkgPath,
                      pkgName, "data", paste(pkgName, i, ".rda", sep = "")))
    }
    # Write elements that has one to many mappings
    for(i in getMultCol4Yeast()){
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(annotation[,"PROBE"],
               lapply(annotation[,i], splitEntry), env)
        assign(paste(pkgName, i, sep = ""), env)
        save(list = paste(pkgName, i, sep = ""), file =  file.path(pkgPath,
             pkgName, "data", paste(pkgName, i, ".rda", sep = "")))
    }
    # GO and CHRLOC have evidence code and chromosome number
    # associated with each entry that needs special attention
    for(i in c("GO", "CHRLOC")){
        if(i == "CHRLOC"){
            num <- TRUE
        }else{
            num <- FALSE
        }
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(annotation[, "PROBE"],
                    lapply(annotation[, i], twoStepSplit,
                               asNumeric = num), env)
        assign(paste(pkgName, i, sep = ""), env)
        save(list = paste(pkgName, i, sep = ""), file =  file.path(pkgPath,
                     pkgName, "data", paste(pkgName, i, ".rda", sep = "")))
    }
    env <- cols2Env(annotation[,c("PMID", "PROBE")],
                    colNames = c("PMID", "PROBE"), keyColName = "PMID")
    assign(paste(pkgName, "PMID2PROBE", sep = ""), env)
    save(list = paste(pkgName, "PMID2PROBE", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "PMID2PROBE.rda", sep = "")))
    if(!is.na(srcUrls["KEGG"])){
        if(base == ""){
            xkey <- "PROBE"
        }else{
            xkey <- "ORF"
        }
        # Adding KEGG pathway data to annoataion
        pathNEnzyme <- mapLL2ECNPName(kegg)
        orfNEC <- pathNEnzyme$llec
        orfNPath <- pathNEnzyme$llpathname
        colnames(orfNEC) <- c("ORF", "ENZYME")
        colnames(orfNPath) <- c("ORF", "PATH")
        annotation <- merge(annotation, orfNPath, by.x = xkey,
                            by.y = "ORF", all.x = TRUE)
        annotation <- merge(annotation, orfNEC, by.x = xkey,
                            by.y = "ORF", all.x = TRUE)
        env <- cols2Env(annotation[,c("PATH", "PROBE")],
                        colNames = c("PATH", "PROBE"), keyColName = "PATH")
        assign(paste(pkgName, "PATH2PROBE", sep = ""), env)
        save(list = paste(pkgName, "PATH2PROBE", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, "PATH2PROBE.rda", sep = "")))
        env <- cols2Env(annotation[,c("ENZYME", "PROBE")],
                        colNames = c("ENZYME", "PROBE"),
                        keyColName = "ENZYME")
        assign(paste(pkgName, "ENZYME2PROBE", sep = ""), env)
        save(list = paste(pkgName, "ENZYME2PROBE", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, "ENZYME2PROBE.rda", sep = "")))
    }
    go2Probe <- new.env(hash = TRUE, parent = NULL)
    multiassign(as.vector(annotation[, "PROBE"]),
                    lapply(annotation[, "GO"], twoStepSplit,
                               asNumeric = FALSE), go2Probe)
    go2Probe <- unlist(multiget(ls(go2Probe), go2Probe))
    go2Probe  <- mergeRowByKey(cbind(go2Probe,
                                     gsub("\\..*", "", names(go2Probe))))
    colnames(go2Probe) <- c("GO", "GO2PROBE")
    # Write GO id to probe id mappings to data package
    env <- new.env(hash = TRUE, parent = NULL)
    multiassign(as.vector(go2Probe[, 1]),
                lapply(go2Probe[, 2], splitEntry), env)
    assign(paste(pkgName, "GO2PROBE", sep = ""), env)
    save(list = paste(pkgName, "GO2PROBE", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "GO2PROBE.rda", sep = "")))
    # Get the mappings between GO ids to all the probe ids (including
    # children)
    options(show.error.messages = FALSE)
    goData <- try(readData(go, xml = TRUE, fromWeb = fromWeb))
    options(show.error.messages = TRUE)
    go2All <- mapGO2AllProbe(go2Probe, goData, "", sep = ";", all = TRUE)
    # colnames(go2All) <- c("GO", "GO2ALLPROBE")
    # Write GO id to all probe ids mappings to data package
    env <- new.env(hash = TRUE, parent = NULL)
    multiassign(names(go2All), sapply(go2All, splitEntry), env)
    assign(paste(pkgName, "GO2ALLPROBES", sep = ""), env)
    save(list = paste(pkgName, "GO2ALLPROBES", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "GO2ALLPROBES.rda", sep = "")))
    go2All <- cbind(names(go2All), go2All)
    colnames(go2All) <- c("GO", "GO2ALLPROBES")
    if(makeXML){
        if(!is.null(go2All) && !is.null(go2Probe)){
            mergedGO <- as.matrix(merge(as.matrix(go2All),
                          as.matrix(go2Probe), by = "GO", all.x = TRUE))
            XMLByNum <- file.path(pkgPath, paste(pkgName, "ByNum.xml",
                                                 sep = ""))
            fileToXML(targetName = "GOByNum", outName = XMLByNum,
                  inName = mergedGO, colNames = "",
                  idColName = "GO", multColNames = c("GO2ALLPROBES",
                                    "GO2PROBE"),
                  typeColNames = "", isFile = FALSE, version = version)
        }
    }
    writeAccessory(pkgName, pkgPath, "yeast", version, author,
                   dataSrc = "Stanford Yeast Genome Project")
    # Write the quality control data
    # Quality control
    if(base == ""){
        base <- getProbe2SGD()
    }
    getDPStats(base, pkgName, pkgPath, isFile = FALSE)
    writeMan4QC(pkgName, pkgPath)
    chrLengths <- findYGChrLength()
    writeOrganism(pkgName, pkgPath, "yeast")
    writeChrLength(pkgName, pkgPath, chrLengths)
    writeManPage(pkgName, pkgPath, "CHRLENGTHS", organism = "yeast",
                 src = "YG", isEnv = FALSE)
    writeManPage(pkgName, pkgPath, "ORGANISM", organism = "yeast",
                 src = NA, isEnv = FALSE)
}

findYGChrLength <- function(yGenoUrl =
    "ftp://genome-ftp.stanford.edu/pub/yeast/data_download/",
    yGenoName = "chromosomal_feature/chromosome_length.tab",
    toKeep = c(1, 3), sep = "\t"){

    ygeno <- YG(srcUrl = yGenoUrl)
    temp <- readData(ygeno, yGenoName, toKeep, sep)
    # Remove the leading and ending space
    temp <- t(apply(temp, 1, function(x) gsub("^ | $", "", x)))
    chrLengths <- temp[,2]
    names(chrLengths) <- temp[,1]

    return(chrLengths)
}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/R/yeastPkgBuilder.R <==
# This function builds a data package for yeast geno.

yeastPkgBuilder <- function(pkgName, pkgPath, base = "", srcUrls = c(KEGG
                            = getSrcUrl("KEGG", organism = "yeast"),
                            GO = getSrcUrl("GO")), version = "1.1.0",
                            makeXML = TRUE, author = list(author = "who",
                            maintainer = "who@email.com"), fromWeb =
                            TRUE){

    getUniCol4Yeast <- function(){
        if(base != ""){
            return(c("PMID", "ORF", "CHR", "DESCRIPTION", "GENENAME"))
        }else{
            return(c("PMID", "CHR", "DESCRIPTION", "GENENAME"))
        }
    }
    getMultCol4Yeast <- function(){
        return("ALIAS")
    }

    if(!is.na(srcUrls["KEGG"])){
        kegg <- KEGG(srcUrl = srcUrls["KEGG"], organism = "yeast")
    }
    if(!is.na(srcUrls["GO"])){
        go <- GO(srcUrl = srcUrls["GO"])
    }

    makeSrcInfo()
    createEmptyDPkg(pkgName, pkgPath, force = TRUE)
    annotation <- yeastAnn(base)
    annotation <- as.matrix(annotation)
    colnames(annotation) <- toupper(colnames(annotation))
    #goNCat <- mapGO2Category(goData)
    #annotation[, "GO"] <- as.vector(unlist(sapply(annotation[, "GO"],
    #                      nameGOByCat, goCat = goNCat), use.names = FALSE))
    goData <- try(readData(go, xml = TRUE, fromWeb = fromWeb))
    if(makeXML){
        multC <- c("PMID", "ALIAS")
        typeC <- c("GO", "CHRLOC")
        XMLOut <- file.path(pkgPath, paste(pkgName, ".xml", sep = ""))
        fileToXML(targetName = pkgName, outName = XMLOut,
                  inName = annotation[, colnames(annotation) != "EVI"],
                  colNames = "", idColName = "PROBE", multColNames = multC,
                  typeColNames = typeC, isFile = FALSE, version = version)
    }
    # Write elements that has one to one mappings
    for(i in getUniCol4Yeast()){
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(annotation[,"PROBE"], as.vector(annotation[,i]), env)
        assign(paste(pkgName, i, sep = ""), env)
        save(list = paste(pkgName, i, sep = ""), file =  file.path(pkgPath,
                      pkgName, "data", paste(pkgName, i, ".rda", sep = "")))
    }
    # Write elements that has one to many mappings
    for(i in getMultCol4Yeast()){
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(annotation[,"PROBE"],
               lapply(annotation[,i], splitEntry), env)
        assign(paste(pkgName, i, sep = ""), env)
        save(list = paste(pkgName, i, sep = ""), file =  file.path(pkgPath,
             pkgName, "data", paste(pkgName, i, ".rda", sep = "")))
    }
    # GO and CHRLOC have evidence code and chromosome number
    # associated with each entry that needs special attention
    #for(i in c("GO", "CHRLOC")){
    #    if(i == "CHRLOC"){
    #        num <- TRUE
    #    }else{
    #        num <- FALSE
    #    }
        env <- new.env(hash = TRUE, parent = NULL)
        multiassign(annotation[, "PROBE"],
                    lapply(annotation[, "CHRLOC"], twoStepSplit,
                               asNumeric = TRUE), env)
        assign(paste(pkgName, "CHRLOC", sep = ""), env)
        save(list = paste(pkgName, "CHRLOC", sep = ""),
             file =  file.path(pkgPath, pkgName, "data", paste(pkgName,
             "CHRLOC", ".rda", sep = "")))
    #}
    goList <- getList4GO(getNamedCat(goData),
                  sapply(annotation[, "GO"], twoStepSplit))
    names(goList) <- annotation[, "PROBE"]
    saveList(goList, "YEAST", pkgPath, "GO")
    env <- cols2Env(annotation[,c("PMID", "PROBE")],
                    colNames = c("PMID", "PROBE"), keyColName = "PMID")
    assign(paste(pkgName, "PMID2PROBE", sep = ""), env)
    save(list = paste(pkgName, "PMID2PROBE", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "PMID2PROBE.rda", sep = "")))
    if(!is.na(srcUrls["KEGG"])){
        if(base == ""){
            xkey <- "PROBE"
        }else{
            xkey <- "ORF"
        }
        # Adding KEGG pathway data to annoataion
        pathNEnzyme <- mapLL2ECNPName(kegg)
        orfNEC <- pathNEnzyme$llec
        orfNPath <- pathNEnzyme$llpathname
        colnames(orfNEC) <- c("ORF", "ENZYME")
        colnames(orfNPath) <- c("ORF", "PATH")
        annotation <- merge(annotation, orfNPath, by.x = xkey,
                            by.y = "ORF", all.x = TRUE)
        annotation <- merge(annotation, orfNEC, by.x = xkey,
                            by.y = "ORF", all.x = TRUE)
        env <- cols2Env(annotation[,c("PATH", "PROBE")],
                        colNames = c("PATH", "PROBE"), keyColName = "PATH")
        assign(paste(pkgName, "PATH2PROBE", sep = ""), env)
        save(list = paste(pkgName, "PATH2PROBE", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, "PATH2PROBE.rda", sep = "")))
        env <- cols2Env(annotation[,c("ENZYME", "PROBE")],
                        colNames = c("ENZYME", "PROBE"),
                        keyColName = "ENZYME")
        assign(paste(pkgName, "ENZYME2PROBE", sep = ""), env)
        save(list = paste(pkgName, "ENZYME2PROBE", sep = ""),
             file =  file.path(pkgPath, pkgName, "data",
             paste(pkgName, "ENZYME2PROBE.rda", sep = "")))
    }
    go2Probe <- new.env(hash = TRUE, parent = NULL)
    multiassign(as.vector(annotation[, "PROBE"]),
                    lapply(annotation[, "GO"], twoStepSplit,
                               asNumeric = FALSE), go2Probe)
    go2Probe <- unlist(contents(go2Probe))
    go2Probe  <- mergeRowByKey(cbind(go2Probe,
                                     gsub("\\..*", "", names(go2Probe))))
    colnames(go2Probe) <- c("GO", "GO2PROBE")
    # Write GO id to probe id mappings to data package
    env <- new.env(hash = TRUE, parent = NULL)
    multiassign(as.vector(go2Probe[, 1]),
                lapply(go2Probe[, 2], splitEntry), env)
    assign(paste(pkgName, "GO2PROBE", sep = ""), env)
    save(list = paste(pkgName, "GO2PROBE", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "GO2PROBE.rda", sep = "")))
    go2All <- mapGO2AllProbe(go2Probe, goData, "", sep = ";", all = TRUE)
    # colnames(go2All) <- c("GO", "GO2ALLPROBE")
    # Write GO id to all probe ids mappings to data package
    env <- new.env(hash = TRUE, parent = NULL)
    multiassign(names(go2All), sapply(go2All, splitEntry), env)
    assign(paste(pkgName, "GO2ALLPROBES", sep = ""), env)
    save(list = paste(pkgName, "GO2ALLPROBES", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "GO2ALLPROBES.rda", sep = "")))
    go2All <- cbind(names(go2All), go2All)
    colnames(go2All) <- c("GO", "GO2ALLPROBES")
    if(makeXML){
        if(!is.null(go2All) && !is.null(go2Probe)){
            mergedGO <- as.matrix(merge(as.matrix(go2All),
                          as.matrix(go2Probe), by = "GO", all.x = TRUE))
            XMLByNum <- file.path(pkgPath, paste(pkgName, "ByNum.xml",
                                                 sep = ""))
            fileToXML(targetName = "GOByNum", outName = XMLByNum,
                  inName = mergedGO, colNames = "",
                  idColName = "GO", multColNames = c("GO2ALLPROBES",
                                    "GO2PROBE"),
                  typeColNames = "", isFile = FALSE, version = version)
        }
    }
    writeAccessory(pkgName, pkgPath, "yeast", version, author,
                   dataSrc = "Stanford Yeast Genome Project")
    # Write the quality control data
    # Quality control
    if(base == ""){
        base <- getProbe2SGD()
    }
    getDPStats(base, pkgName, pkgPath, isFile = TRUE)
    writeMan4QC(pkgName, pkgPath)
    chrLengths <- getChrLengths("yeast")
    writeOrganism(pkgName, pkgPath, "yeast")
    writeChrLength(pkgName, pkgPath, chrLengths)
    writeManPage(pkgName, pkgPath, "CHRLENGTHS", organism = "yeast",
                 src = "YG", isEnv = FALSE)
    writeManPage(pkgName, pkgPath, "ORGANISM", organism = "yeast",
                 src = NA, isEnv = FALSE)
}
